# (tv) fix build:
%define _disable_ld_no_undefined 0

# (tv) fix requires:
%global __requires_exclude devel\\(libclang

%define major 3.9
%define minor 1

%define libname %mklibname clang %major
%define devname %mklibname -d clang

Name:		clang
Version:	%major.%minor
Release:	%mkrel 4
Summary:	A C language family front-end for LLVM
Group:		Development/Other

License:	NCSA
URL:		http://llvm.org
Source0:	http://llvm.org/releases/%{version}/cfe-%{version}.src.tar.xz
Patch10:	cfe-3.9.1-detect-Mageia.patch

BuildRequires:	cmake
BuildRequires:	llvm-devel >= %{version}-5
BuildRequires:	libxml2-devel
BuildRequires:  llvm-static >= %{version}-5

Requires:	%{libname} = %{version}-%{release}

# clang requires gcc, clang++ requires libstdc++-devel
# - https://bugzilla.redhat.com/show_bug.cgi?id=1021645
# - https://bugzilla.redhat.com/show_bug.cgi?id=1158594
Requires:	libstdc++-devel
Requires:	gcc-c++


%description
clang: noun
    1. A loud, resonant, metallic sound.
    2. The strident call of a crane or goose.
    3. C-language family front-end toolkit.

The goal of the Clang project is to create a new C, C++, Objective C
and Objective C++ front-end for the LLVM compiler. Its tools are built
as libraries and designed to be loosely-coupled and extensible.

%package -n %libname
Summary: Runtime library for clang
# compiler-rt does not support arm5tl
%ifnarch armv5tl
Requires: compiler-rt >= %{version}
%endif
%description -n %libname
Runtime library for clang.

%package -n %devname
Summary: Development header files for clang
Requires: %{libname} = %{version}-%{release}
Provides: clang-devel = %version-%release

%description -n %devname
Development header files for clang.

%package analyzer
Summary:	A source code analysis framework
License:	NCSA and MIT
BuildArch:	noarch
Requires:	%{name} = %{version}-%{release}
# not picked up automatically since files are currently not installed in
# standard Python hierarchies yet
Requires:	python

%description analyzer
The Clang Static Analyzer consists of both a source code analysis
framework and a standalone tool that finds bugs in C and Objective-C
programs. The standalone tool is invoked from the command-line, and is
intended to run in tandem with a build of a project or code base.

%prep
%setup -q -n cfe-%{version}.src
%patch10 -p1 -b .TRIPLETS
%build
# FC compatibility:
ln -sf build _build
%global _cmake_skip_rpath %nil
%cmake .. \
	-DLLVM_LINK_LLVM_DYLIB:BOOL=ON \
	-DCMAKE_BUILD_TYPE=RelWithDebInfo \
	-DLLVM_CONFIG:FILEPATH=/usr/bin/llvm-config \
	\
	-DCLANG_ENABLE_ARCMT:BOOL=ON \
	-DCLANG_ENABLE_STATIC_ANALYZER:BOOL=ON \
	-DCLANG_INCLUDE_DOCS:BOOL=ON \
	-DCLANG_INCLUDE_TESTS:BOOL=ON \
	-DCLANG_PLUGIN_SUPPORT:BOOL=ON \
	\
	-DCLANG_BUILD_EXAMPLES:BOOL=OFF \
%if 0%{?__isa_bits} == 64
	-DLLVM_LIBDIR_SUFFIX=64 \
%else
	-DLLVM_LIBDIR_SUFFIX= \
%endif
	-DLIB_SUFFIX=

%make

%install
cd _build
%make_install

# remove git integration
rm -vf %{buildroot}%{_bindir}/git-clang-format
# remove editor integrations (bbedit, sublime, emacs, vim)
rm -vf %{buildroot}%{_datadir}/clang/clang-format-bbedit.applescript
rm -vf %{buildroot}%{_datadir}/clang/clang-format-sublime.py*
rm -vf %{buildroot}%{_datadir}/clang/clang-format.el
rm -vf %{buildroot}%{_datadir}/clang/clang-format.py*
# remove diff reformatter
rm -vf %{buildroot}%{_datadir}/clang/clang-format-diff.py*

%check
# requires lit.py from LLVM utilities
#cd _build
#make check-all

%files
%{_libdir}/clang/
%{_bindir}/clang*
%{_bindir}/c-index-test

%files -n %libname
%{_libdir}/*.so.*
%{_libdir}/*.so

%files -n %devname
%{_includedir}/clang/
%{_includedir}/clang-c/
%dir %{_datadir}/clang/
%{_libdir}/cmake/

%files analyzer
%{_bindir}/scan-view
%{_bindir}/scan-build
%{_bindir}/scan-build
%{_libexecdir}/ccc-analyzer
%{_libexecdir}/c++-analyzer
%{_datadir}/scan-view/
%{_datadir}/scan-build/
%{_mandir}/man1/scan-build.1.*



%changelog
* Tue Mar 28 2017 tmb <tmb> 3.9.1-4.mga6
+ Revision: 1095109
- rebuild for armv7hl

* Tue Mar 28 2017 tmb <tmb> 3.9.1-3.mga6
+ Revision: 1095072
- dont require compiler-rt on armv5tl

* Tue Mar 28 2017 tmb <tmb> 3.9.1-2.mga6
+ Revision: 1095014
- rebuild with new llvm

* Sat Jan 07 2017 ghibo <ghibo> 3.9.1-1.mga6
+ Revision: 1080455
- Update to release 3.9.1.
- Removed GCC patches (merged upstream).
- Rework Patch10 for Mageia detecting.

* Mon Oct 03 2016 tv <tv> 3.8.1-4.mga6
+ Revision: 1058299
- add GCC abi_tag support (rhbz#1282645)

* Thu Sep 08 2016 pterjan <pterjan> 3.8.1-3.mga6
+ Revision: 1050874
- Add armv5tl-mageia-linux-gnueabi, hopefuly at the correct place
- Add armv7hl-mageia-linux-gnueabi

  + shlomif <shlomif>
    - Fix clang invocation on mageia ( MGA#18138 ).
    - Copy a patch from the old llvm package that was left out after clang was
      split from it. We still need to handle the ARM architecture.

* Tue Jul 12 2016 tmb <tmb> 3.8.1-2.mga6
+ Revision: 1041254
- update to 3.8.1 (maintenance release)

* Tue Mar 29 2016 pterjan <pterjan> 3.8.0-9.mga6
+ Revision: 996290
- Rebuild to get it on arm

* Tue Mar 15 2016 tv <tv> 3.8.0-8.mga6
+ Revision: 990894
- rebuild b/c clang-analyzer was not uploaded by BS

* Mon Mar 14 2016 tv <tv> 3.8.0-7.mga6
+ Revision: 990522
- submit to core/release

* Sat Mar 12 2016 tv <tv> 3.8.0-6.mga6
+ Revision: 989660
- fix lib requires
- provides clang-devel

* Sat Mar 12 2016 tv <tv> 3.8.0-4.mga6
+ Revision: 989586
- fix requires

* Sat Mar 12 2016 tv <tv> 3.8.0-3.mga6
+ Revision: 989532
- fix upload (summary-ended-with-dot)
- adjust file list
- fix linking
- 3.8.0 final
- imported package clang

  + tmb <tmb>
    - try to disable parallell build


* Tue Mar 08 2016 Thierry Vignaud <tv@mageia.org> 3.8.0-1.mga6
- import from FC
